#!/usr/bin/ruby

require 'sensu-plugin/check/cli'
require 'restclient'
require 'json'

class SensuPluginsEecStatus < Sensu::Plugin::Check::CLI

  option :server,
    short: '-s eec.local',
    description: 'DNS endpoint of your EEC server',
    default: 'localhost'

  option :delay_max,
    short: '-d 10',
    description: 'Maximum number of seconds allowed before we alert',
    default: 10

  def run
    url="http://#{config[:server]}/monitoring/heartbeat"

    result = RestClient.get url
    critical("no result returnd") if result.body.length <= 0

    result = JSON.parse(result)
    if result["delay_seconds"].to_i > config[:delay_max].to_i
      critical("EEC server delay is beyond maximum allowd limit of #{config[:delay_max]} seconds, delay is now: #{result["delay_seconds"]} seconds")
    else
      ok("EEC server delay is reporting delay of #{result["delay_seconds"]} seconds, limit of #{config[:delay_max]} seconds")
    end
  end

end
